pm4py.algo.conformance.footprints.variants package
==================================================

Submodules
----------

pm4py.algo.conformance.footprints.variants.log\_extensive module
----------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.footprints.variants.log_extensive
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.footprints.variants.log\_model module
------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.footprints.variants.log_model
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.footprints.variants.trace\_extensive module
------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.footprints.variants.trace_extensive
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.footprints.variants
   :members:
   :undoc-members:
   :show-inheritance:
